@@ -25,7 +25,7 @@ sub _run {
     my ($self) = @_;
     return sub {
         my $req = Lemonldap::NG::Common::PSGI::Request->new( $_[0] );
-        my $res = $self->_authAndTrace($req);
+        my $res = $self->_logAuthTrace($req);
         push @{ $res->[1] }, $req->spliceHdrs,
           Cookie => ( $req->{Cookie} // '' );
         return $res;
